@@ -116,6 +116,16 @@ int init(char* config_file, void* config) // Returns filedescriptor for uinput d
   if (uinput_fd > 0) printf("Accelemymote driver successfully installed for use as joystick.\n");
   else return 0;
 
+  if (ini_parse(config_file, handler, config) < 0) {
+    printf("Error: can't load configuration from %s!\n", config_file);
+    return 0;
+  }
+
+  //TODO: Error/bounds/defaults for configuration values
+
+  printf("Config loaded from %s. Profile=%s and poll rate=%d/s.\n",
+    config_file, ((configuration*)config)->profile, ((configuration*)config)->frame_rate*((configuration*)config)->samples);
+
   /* If no trigger_filename is set, the process will run indefinitely.*/
   if (trigger_filename[0])
   {
@@ -130,15 +140,6 @@ int init(char* config_file, void* config) // Returns filedescriptor for uinput d
     printf("No trigger file specified. Kill service process when finished.\n");
   }
 
-  if (ini_parse(config_file, handler, config) < 0) {
-    printf("Error: can't load configuration from %s!\n", config_file);
-    return 0;
-  }
-
-  //TODO: Error/bounds/defaults for configuration values
-
-  printf("Config loaded from %s. Profile=%s and poll rate=%d/s.\n",
-    config_file, ((configuration*)config)->profile, ((configuration*)config)->frame_rate*((configuration*)config)->samples);
   return uinput_fd;
 }
 
@@ -147,7 +148,7 @@ int main(int argc, char **argv)
 {
   int uinput_fd; 
   int ax, ay, az;
-  float normalize; // Sqrt of sum of squares
+  float acc; // Total acceleration (Sqrt of sum of squares)
   float offset_pitch; //Radians to neutral position
 
   // Roll and pitch in radians
@@ -175,33 +176,32 @@ int main(int argc, char **argv)
 
   if (strcasecmp(config.profile, "debug") == 0) debug = 1;
 
-  while(1) { // Begin main loop. This only exits if a trigger file was specified and it is deleted.
+  while(1) { // Begin main loop. This only exits if a trigger file that was specified is deleted.
 
     read_errors+= do_poll(config.samples, &sample_interval, &ax, &ay, &az);
     frames++;
     if (!(frames % 200) && trigger_filename[0] && access(trigger_filename, F_OK)) break; // infrequently check if trigger file is gone
  
-    // TODO: Keep state and/or watch total acceleration to subtract out "gestures".
-    // Also, the math could probably use some work.
-    normalize = sqrtf(((long)ax)*ax + ((long)ay)*ay + ((long)az)*az);  //Use long to avoid overflow when squaring ~1000 to normalize!
+    // TODO: Keep state and/or watch total acceleration to subtract out "gestures". Also, the math could probably use some work.
+    acc = sqrtf(((long)ax)*ax + ((long)ay)*ay + ((long)az)*az);  //Use long to avoid overflow when squaring ~1000 to get vector length!
 
-    current.pitch = asinf( ay / normalize)+offset_pitch;
-    current.roll = -asinf( ax / normalize);
-    if (debug && !(frames%24)) printf("Frame: accel(%d,%d,%d); normalization %0.0f. Tilt (%0.2f,%0.2f) with offset %0.2f included.\n",ax,ay,az,normalize,current.pitch, current.roll, offset_pitch);
+    current.pitch = asinf(ay / acc)+offset_pitch;
+    current.roll = -asinf(ax / acc);
+    if (debug && !(frames%24)) printf("Frame: acceleration(%d,%d,%d)=%.0f. Tilt (%0.2f,%0.2f) with offset %0.2f included.\n",ax,ay,az,acc,current.pitch, current.roll, offset_pitch);
 
     clamp(&current.pitch, max.pitch), clamp(&current.roll, max.roll);
     
     // Send significantly changed control states to UINPUT
-//    if ((current.roll-previous.roll) * (current.roll-previous.roll) > threshold.roll*threshold.roll) // abs()
-//    {
-      do_uinput(uinput_fd, ABS_X, (current.roll/max.roll) * (MAX_AXIS/2), EV_ABS); //Currently only emulates keypresses ("hat" profile)
+    if ((current.roll-previous.roll) * (current.roll-previous.roll) > threshold.roll*threshold.roll) // abs()
+    {
+      do_uinput(uinput_fd, ABS_X, (current.roll/max.roll) * (MAX_AXIS/2), EV_ABS);
       previous.roll = current.roll;
-//    }
-//    if ((current.pitch-previous.pitch) * (current.pitch-previous.pitch) > threshold.pitch*threshold.pitch) // abs()
-//    {
+    }
+    if ((current.pitch-previous.pitch) * (current.pitch-previous.pitch) > threshold.pitch*threshold.pitch) // abs()
+    {
       do_uinput(uinput_fd, ABS_Y, ((current.pitch/max.pitch) * (MAX_AXIS/2) * config.flip_pitch), EV_ABS);
       previous.pitch = current.pitch;
-//    }
+    }
 
   } // End main loop
 
